@@ -6,7 +6,7 @@ use 5.005;
 
 BEGIN {
 	$thanks::AUTHORITY = 'cpan:TOBYINK' unless $thanks::AUTHORITY;
-	$thanks::VERSION   = '0.004'        unless $thanks::VERSION;
+	$thanks::VERSION   = '0.005'        unless $thanks::VERSION;
 }
 
 sub _module_notional_filename
@@ -31,7 +31,7 @@ __END__
 
 =head1 NAME
 
-thanks - no thanks, I don't want that module
+thanks - inline packages easily
 
 =head1 SYNOPSIS
 
@@ -45,6 +45,19 @@ thanks - no thanks, I don't want that module
 	                  # file "My/Package.pm".
 	                  #
 
+Or:
+
+	BEGIN {
+		package My::Package;
+		# everything else goes here
+	};
+	
+	no thanks qw( My::Package Another::Package Yet::Another::Package );
+	
+	use My::Package;  # No error message about missing
+	                  # file "My/Package.pm".
+	                  #
+
 =head1 ELEVATOR PITCH
 
 Defining multiple Perl packages in the same file can be fraught with
@@ -144,7 +157,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 by Toby Inkster.
+This software is copyright (c) 2012-2013 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
